API
===

.. module:: irmetrics

This this is the full API reference of all public methods.

Metrics
----------

.. automodule:: irmetrics.topk
    :members:

.. automodule:: irmetrics.coverage
    :members:


Utilities
---------

.. automodule:: irmetrics.relevance
    :members:

.. automodule:: irmetrics.flat
    :members:
